@@ -33,6 +33,9 @@
 #include "gdmconfig.h"
 #include "gdmsession.h"
 
+#include "gdm-common.h"
+#include "gdm-daemon-config-keys.h"
+
 #include "greeter.h"
 #include "greeter_session.h"
 #include "greeter_item_pam.h"
